==> haskell-http-conduit-2.3.8.3-48-riscv64.pkg.tar.zst: usr/share/haskell/register/haskell-http-conduit.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name:                 http-conduit
version:              2.3.8.3
visibility:           public
id:                   http-conduit-2.3.8.3-1nsQ6LY8l6ZCKHc2yiI82m
key:                  http-conduit-2.3.8.3-1nsQ6LY8l6ZCKHc2yiI82m
license:              BSD-3-Clause
maintainer:           Michael Snoyman <michael@snoyman.com>
author:               Michael Snoyman <michael@snoyman.com>
stability:            Stable
homepage:             https://github.com/snoyberg/http-client
synopsis:
    HTTP client package with conduit interface and HTTPS support.

description:
    Hackage documentation generation is not reliable. For up to date documentation, please see: <http://www.stackage.org/package/http-conduit>.

category:             Web, Conduit
abi:                  79f4336cfb69f029c1129476d6ac78e3
exposed:              True
exposed-modules:
    Network.HTTP.Client.Conduit Network.HTTP.Conduit
    Network.HTTP.Simple

import-dirs:          /usr/lib/ghc-9.2.8/site-local/http-conduit-2.3.8.3
library-dirs:         /usr/lib/ghc-9.2.8/site-local/http-conduit-2.3.8.3
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-http-conduit
hs-libraries:         HShttp-conduit-2.3.8.3-1nsQ6LY8l6ZCKHc2yiI82m
depends:
    aeson-2.1.2.1-1R35DvuKsJwFudsOlCM6yV
    attoparsec-0.14.4-l6gpYVAuXa4krkAJlMwbn
    attoparsec-aeson-2.1.0.0-D2SWchNoil66qsxvPlcd3h base-4.16.4.0
    bytestring-0.11.4.0 conduit-1.3.5-9fqCSsgtXVG2zpv5ZVEi4s
    conduit-extra-1.3.6-AEwfYIT97IN5iosArwGxsb
    http-client-0.7.15-DQnyZx9lzoSgMdf26TxD3
    http-client-tls-0.3.6.3-vm9lZXKKPQG6YiMQwXwb7
    http-types-0.12.4-B3znMwHTe3dL304Bd3IJgZ mtl-2.2.2
    resourcet-1.2.6-L3rnNUXQIyNIGkCgFQVXFM transformers-0.5.6.2
    unliftio-core-0.2.1.0-2wlRerPMhUe3AYGiMsYOzn

haddock-interfaces:
    /usr/share/doc/haskell-http-conduit/html/http-conduit.haddock

haddock-html:         /usr/share/doc/haskell-http-conduit/html
' | '/usr/bin/ghc-pkg-9.2.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-http-conduit-2.3.8.3-71-riscv64.pkg.tar.zst: usr/share/haskell/register/haskell-http-conduit.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name:                 http-conduit
version:              2.3.8.3
visibility:           public
id:                   http-conduit-2.3.8.3-KkBMXrBtxP6LrN8a2mfNMZ
key:                  http-conduit-2.3.8.3-KkBMXrBtxP6LrN8a2mfNMZ
license:              BSD-3-Clause
maintainer:           Michael Snoyman <michael@snoyman.com>
author:               Michael Snoyman <michael@snoyman.com>
stability:            Stable
homepage:             https://github.com/snoyberg/http-client
synopsis:
    HTTP client package with conduit interface and HTTPS support.

description:
    Hackage documentation generation is not reliable. For up to date documentation, please see: <http://www.stackage.org/package/http-conduit>.

category:             Web, Conduit
abi:                  156766d5164231280b7e9150f28de72b
exposed:              True
exposed-modules:
    Network.HTTP.Client.Conduit Network.HTTP.Conduit
    Network.HTTP.Simple

import-dirs:          /usr/lib/ghc-9.2.8/site-local/http-conduit-2.3.8.3
library-dirs:         /usr/lib/ghc-9.2.8/site-local/http-conduit-2.3.8.3
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-http-conduit
hs-libraries:         HShttp-conduit-2.3.8.3-KkBMXrBtxP6LrN8a2mfNMZ
depends:
    aeson-2.1.2.1-4G6NRH3Yicj9TKX8fXoWTr
    attoparsec-0.14.4-7zFXPvsAeTc17D9FbG47Bq
    attoparsec-aeson-2.1.0.0-Dv7oW4CsUXjKQqMNZaLFPh base-4.16.4.0
    bytestring-0.11.4.0 conduit-1.3.6-6d8V4DJENsC1laAutlfv9x
    conduit-extra-1.3.6-GQSgUNMr0ZN9ENRzkRi4eD
    http-client-0.7.15-15pF87z30Lb260fGpQvD7x
    http-client-tls-0.3.6.3-7PKwybeQpZP3STjfZ1Ty3Q
    http-types-0.12.4-4jA7skhyc4O1mTcupRz8pv mtl-2.2.2
    resourcet-1.2.6-KSYfCEph27i1WbA0p8CCrD transformers-0.5.6.2
    unliftio-core-0.2.1.0-2wlRerPMhUe3AYGiMsYOzn

haddock-interfaces:
    /usr/share/doc/haskell-http-conduit/html/http-conduit.haddock

haddock-html:         /usr/share/doc/haskell-http-conduit/html
' | '/usr/bin/ghc-pkg-9.2.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
